@@ -3,9 +3,11 @@
 #define PCI_OS_LINUX
 #define PCI_HAVE_PM_LINUX_SYSFS
 #define PCI_HAVE_PM_LINUX_PROC
+#define PCI_HAVE_PM_MMIO_CONF
 #define PCI_HAVE_LINUX_BYTEORDER_H
 #define PCI_PATH_PROC_BUS_PCI "/proc/bus/pci"
 #define PCI_PATH_SYS_BUS_PCI "/sys/bus/pci"
+#define PCI_PATH_DEVMEM_DEVICE "/dev/mem"
 #define PCI_HAVE_64BIT_ADDRESS
 #define PCI_HAVE_PM_DUMP
 #define PCI_IDS "pci.ids"
@@ -14,4 +16,4 @@
 #define PCI_ID_DOMAIN "pci.id.ucw.cz"
 #define PCI_USE_LIBKMOD
 #define PCI_SHARED_LIB
-#define PCILIB_VERSION "3.8.0"
+#define PCILIB_VERSION "3.9.0"
